package net.lapisblue.server.images;

import java.awt.*;
import java.awt.image.*;
import java.text.*;
import java.io.*;
import java.util.*;
import javax.imageio.*;
import javax.servlet.*;
import javax.servlet.http.*;

public class ButtonServlet extends ImageServlet {
  class ButtonGenerator extends ImageGenerator {
    final int width;
    final int height;
    final String labelFontFace;
    final int labelFontSize;
    final Color buttonColor;
    final Color labelColor;
    final String label;
    
    ButtonGenerator (HttpServletRequest request) {
      super(request);

      this.width = getInt("w");
      this.height = getInt("h");
      this.buttonColor = getColor("buttonColor");
      this.labelColor = getColor("labelColor");
      this.labelFontSize = getInt("labelFontSize");
      this.labelFontFace = getString("labelFontFace");
      this.label = getString("label");
    }
    
    protected int getImageWidth () { return width; }
    protected int getImageHeight () { return height; }
    
    protected void draw (Graphics2D g2d) {
      g2d.setRenderingHint(RenderingHints.KEY_ANTIALIASING,
                           RenderingHints.VALUE_ANTIALIAS_ON);

      Font font = new Font(labelFontFace, Font.PLAIN, labelFontSize);
      
      g2d.setFont(font);
      
      final FontMetrics fm = g2d.getFontMetrics();
      
      g2d.setColor(buttonColor);
      
      g2d.fillRoundRect(1, 1, width-2, height-2, height/3, height/3);
      
      g2d.setPaint(new GradientPaint(0, 4, new Color(1f,1f,1f,0.5f), 
                                     0, height/3,
                                     new Color(buttonColor.getRed(), 
                                               buttonColor.getGreen(), 
                                               buttonColor.getBlue(),
                                               128), true));
      
      //       g2d.fillRoundRect(1, 1, width-2, height-2, height-2, height-2);
      g2d.fillRoundRect(1, 1, width-2, height/3, height/3, height/3);
      
      g2d.setColor(labelColor);
      
      int w = fm.stringWidth(label);
        
      g2d.drawString(label, (width - w)/2, (height + fm.getAscent()) / 2);
    }
  }
  
  protected ImageGenerator createImageGenerator (HttpServletRequest request) {
    return new ButtonGenerator(request);
  }
}